"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.callHttpMethod = exports.isHttpMethod = void 0;
const send_request_1 = require("./send-request");
const json_transform_1 = require("./json-transform");
function isHttpMethod(methodCfg) {
    return methodCfg && methodCfg.type === 'http';
}
exports.isHttpMethod = isHttpMethod;
/**
 * 调用HTTP方法
 */
function callHttpMethod(options, context) {
    return send_request_1.sendRequest(options.dsConfig, options.methodCfg, context, options.params)
        .then(({ response, body }) => {
        if (options.isTestMode) {
            return { response, body };
        }
        const bodyType = typeof body;
        let parsedBody;
        if (bodyType === 'object') {
            parsedBody = body;
        }
        else if (bodyType === 'string') {
            try {
                parsedBody = JSON.parse(body);
            }
            catch (error) {
                throw new Error(`invalid response body, expect a json string: ${body}`);
            }
        }
        else {
            throw new Error(`unsupported response body type ${bodyType}`);
        }
        try {
            const result = json_transform_1.transformJSONWithTemplate(parsedBody, options.methodCfg.outParams);
            return {
                code: 0,
                data: result,
            };
        }
        catch (error) {
            throw new Error(`failed to map origin response to method ${options.methodName}'s outParams specified structure`);
        }
    });
}
exports.callHttpMethod = callHttpMethod;
